@@ -4,16 +4,16 @@
  * Authors: Arun Raghavan <arun.raghavan@collabora.co.uk>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -60,11 +60,11 @@ G_BEGIN_DECLS
  * The top-level object used to for metadata extraction.
  */
 typedef struct {
-        GstDiscoverer parent;
+        GstDiscovererInternal parent;
 } GUPnPDLNADiscoverer;
 
 typedef struct {
-        GstDiscovererClass parent_class;
+        GstDiscovererInternalClass parent_class;
 
         /*< signals >*/
         void (*done) (GUPnPDLNADiscoverer *discoverer,
@@ -72,7 +72,7 @@ typedef struct {
                       GError *err);
 
         /*< private >*/
-        GList *profiles_list;
+        GList *profiles_list[2][2];
 
 } GUPnPDLNADiscovererClass;
 
@@ -85,9 +85,9 @@ gupnp_dlna_discoverer_new (GstClockTime timeout,
 
 /* Asynchronous API */
 #define gupnp_dlna_discoverer_start(discoverer) \
-        gst_discoverer_start(GST_DISCOVERER((discoverer)))
+        gst_discoverer_internal_start(GST_DISCOVERER_INTERNAL((discoverer)))
 #define gupnp_dlna_discoverer_stop(discoverer) \
-        gst_discoverer_stop(GST_DISCOVERER((discoverer)))
+        gst_discoverer_internal_stop(GST_DISCOVERER_INTERNAL((discoverer)))
 gboolean
 gupnp_dlna_discoverer_discover_uri (GUPnPDLNADiscoverer *discoverer,
                                     gchar               *uri);
